@@ -2,7 +2,7 @@
 # Kernel/System/TemplateGenerator.pm - generate salutations, signatures and responses
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: TemplateGenerator.pm,v 1.53.2.1 2012/06/04 10:20:43 mg Exp $
+# $Id: TemplateGenerator.pm,v 1.59 2012/03/01 01:20:09 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -21,9 +21,13 @@ use Kernel::System::SystemAddress;
 use Kernel::System::StandardResponse;
 use Kernel::System::Notification;
 use Kernel::System::AutoResponse;
+use Kernel::Language;
+use Kernel::System::DynamicField;
+use Kernel::System::DynamicField::Backend;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.53.2.1 $) [1];
+$VERSION = qw($Revision: 1.59 $) [1];
 
 =head1 NAME
 
@@ -151,6 +155,17 @@ sub new {
     $Self->{StandardResponseObject} = Kernel::System::StandardResponse->new(%Param);
     $Self->{NotificationObject}     = Kernel::System::Notification->new(%Param);
     $Self->{AutoResponseObject}     = Kernel::System::AutoResponse->new(%Param);
+    $Self->{DynamicFieldObject}     = Kernel::System::DynamicField->new(%Param);
+    $Self->{BackendObject}          = Kernel::System::DynamicField::Backend->new(
+        TimeObject => $Self->{TicketObject}->{TimeObject},
+        %Param
+    );
+
+    # get the dynamic fields for ticket object
+    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid      => 1,
+        ObjectType => ['Ticket'],
+    );
 
     return $Self;
 }
@@ -182,7 +197,10 @@ sub Salutation {
     }
 
     # get  queue
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     # get salutation
     my %Queue = $Self->{QueueObject}->QueueGet(
@@ -269,7 +287,10 @@ sub Signature {
     # get salutation ticket based
     my %Queue;
     if ( $Param{TicketID} ) {
-        my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+        my %Ticket = $Self->{TicketObject}->TicketGet(
+            TicketID      => $Param{TicketID},
+            DynamicFields => 0,
+        );
         %Queue = $Self->{QueueObject}->QueueGet(
             ID => $Ticket{QueueID},
         );
@@ -429,7 +450,10 @@ sub Response {
     }
 
     # get  queue
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     # get salutation
     my %Queue = $Self->{QueueObject}->QueueGet(
@@ -507,7 +531,10 @@ sub Attributes {
     }
 
     # get queue
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     # prepare subject ...
     $Param{Data}->{Subject} = $Self->{TicketObject}->TicketSubjectBuild(
@@ -566,7 +593,10 @@ sub AutoResponse {
     }
 
     # get ticket
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     # get auto default responses
     my %AutoResponse = $Self->{AutoResponseObject}->AutoResponseGetByTypeQueueID(
@@ -578,7 +608,8 @@ sub AutoResponse {
 
     # get old article for quoting
     my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
-        TicketID => $Param{TicketID},
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
     );
 
     for (qw(From To Cc Subject Body)) {
@@ -591,11 +622,7 @@ sub AutoResponse {
     # format body (only if longer the 86 chars)
     if ( $Param{OrigHeader}->{Body} ) {
         if ( length $Param{OrigHeader}->{Body} > 86 ) {
-            my @lines = split /\n/, $Param{OrigHeader}->{Body};
-            for my $line (@lines) {
-                $line =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
-            }
-            $Param{OrigHeader}->{Body} = join '', @lines;
+            $Param{OrigHeader}->{Body} =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
         }
     }
 
@@ -691,7 +718,7 @@ sub AutoResponse {
 
 generate response
 
-NotifcationAgent
+NotificationAgent
     TicketID
         Owner
         Responsible
@@ -731,10 +758,16 @@ sub NotificationAgent {
     }
 
     # get ticket
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     # get old article for quoting
-    my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle( TicketID => $Param{TicketID} );
+    my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     for (qw(From To Cc Subject Body)) {
         if ( !$Param{CustomerMessageParams}->{$_} ) {
@@ -746,11 +779,7 @@ sub NotificationAgent {
     # format body (only if longer the 86 chars)
     if ( $Param{CustomerMessageParams}->{Body} ) {
         if ( length $Param{CustomerMessageParams}->{Body} > 86 ) {
-            my @lines = split /\n/, $Param{CustomerMessageParams}->{Body};
-            for my $line (@lines) {
-                $line =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
-            }
-            $Param{CustomerMessageParams}->{Body} = join '', @lines;
+            $Param{CustomerMessageParams}->{Body} =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
         }
     }
 
@@ -806,6 +835,7 @@ sub NotificationAgent {
         Data        => $Param{CustomerMessageParams},
         TicketID    => $Param{TicketID},
         UserID      => $Param{UserID},
+        Language    => $Language,
     );
     $Notification{Subject} = $Self->_Replace(
         RichText    => 0,
@@ -814,6 +844,7 @@ sub NotificationAgent {
         Data        => $Param{CustomerMessageParams},
         TicketID    => $Param{TicketID},
         UserID      => $Param{UserID},
+        Language    => $Language,
     );
 
     # prepare subject (insert old subject)
@@ -854,7 +885,7 @@ sub NotificationAgent {
 
 generate response
 
-NotifcationCustomer
+NotificationCustomer
     TicketID
         Owner
         Responsible
@@ -894,7 +925,10 @@ sub NotificationCustomer {
         }
     }
 
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     my %Queue;
     if ( $Param{QueueID} ) {
@@ -927,6 +961,7 @@ sub NotificationCustomer {
             Text     => $Notification{$_},
             TicketID => $Param{TicketID},
             UserID   => $Param{UserID},
+            Language => $Language,
         );
     }
 
@@ -963,7 +998,24 @@ sub _Replace {
 
     my %Ticket;
     if ( $Param{TicketID} ) {
-        %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+        %Ticket = $Self->{TicketObject}->TicketGet(
+            TicketID      => $Param{TicketID},
+            DynamicFields => 1,
+        );
+    }
+
+    # translate ticket values if needed
+    if ( $Param{Language} ) {
+        my $LanguageObject = Kernel::Language->new(
+            MainObject   => $Self->{MainObject},
+            ConfigObject => $Self->{ConfigObject},
+            EncodeObject => $Self->{EncodeObject},
+            LogObject    => $Self->{LogObject},
+            UserLanguage => $Param{Language},
+        );
+        for my $Field (qw(Type State StateType Lock Priority)) {
+            $Ticket{$Field} = $LanguageObject->Get( $Ticket{$Field} );
+        }
     }
 
     my %Queue;
@@ -1104,6 +1156,23 @@ sub _Replace {
         }
     }
 
+    # cycle trough the activated Dynamic Fields for this screen
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+        # get the readable value for each dynamic field
+        my $ValueStrg = $Self->{BackendObject}->ReadableValueRender(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            Value              => $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} },
+        );
+
+        # replace ticket content with the value from ReadableValueRender (if any)
+        if ( IsHashRefWithData($ValueStrg) ) {
+            $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} } = $ValueStrg->{Value};
+        }
+    }
+
     # replace it
     for ( keys %Ticket ) {
         next if !defined $Ticket{$_};
@@ -1350,6 +1419,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.53.2.1 $ $Date: 2012/06/04 10:20:43 $
+$Revision: 1.59 $ $Date: 2012/03/01 01:20:09 $
 
 =cut
